==> haskell-tasty-inspection-testing-0.2.1-13.2-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-inspection-testing.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-inspection-testing
version:              0.2.1
visibility:           public
id:                   tasty-inspection-testing-0.2.1-3l2B3Hh9rXAD60lKq0WCDR
key:                  tasty-inspection-testing-0.2.1-3l2B3Hh9rXAD60lKq0WCDR
license:              MIT
copyright:            2017 Joachim Breitner, 2021 Andrew Lelechenko
maintainer:           Andrew Lelechenko <andrew.lelechenko@gmail.com>
author:               Joachim Breitner, Andrew Lelechenko
homepage:             https://github.com/Bodigrim/tasty-inspection-testing
synopsis:             Inspection testing support for tasty
description:          Integrate @inspection-testing@ into @tasty@ test suites.
category:             Testing
abi:                  675cda92919bd8c8635ff553f9a72373
exposed:              True
exposed-modules:      Test.Tasty.Inspection Test.Tasty.Inspection.Plugin
hidden-modules:       Test.Tasty.Inspection.Internal
import-dirs:
    /usr/lib/ghc-9.2.8/site-local/tasty-inspection-testing-0.2.1

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/tasty-inspection-testing-0.2.1

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-inspection-testing
hs-libraries:         HStasty-inspection-testing-0.2.1-3l2B3Hh9rXAD60lKq0WCDR
depends:
    base-4.16.4.0 ghc-9.2.8
    inspection-testing-0.5.0.3-2OudPLUZJQj32eoiHRYWC6
    tasty-1.4.3-45V6IUrFvI6FX8Qf0XPHba template-haskell-2.18.0.0

haddock-interfaces:
    /usr/share/doc/haskell-tasty-inspection-testing/html/tasty-inspection-testing.haddock

haddock-html:         /usr/share/doc/haskell-tasty-inspection-testing/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-inspection-testing-0.2.1-17.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-inspection-testing.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-inspection-testing
version:              0.2.1
visibility:           public
id:                   tasty-inspection-testing-0.2.1-4eXeMfIk9OsKHH1rKdGx4n
key:                  tasty-inspection-testing-0.2.1-4eXeMfIk9OsKHH1rKdGx4n
license:              MIT
copyright:            2017 Joachim Breitner, 2021 Andrew Lelechenko
maintainer:           Andrew Lelechenko <andrew.lelechenko@gmail.com>
author:               Joachim Breitner, Andrew Lelechenko
homepage:             https://github.com/Bodigrim/tasty-inspection-testing
synopsis:             Inspection testing support for tasty
description:          Integrate @inspection-testing@ into @tasty@ test suites.
category:             Testing
abi:                  f896afebee1b00b129e183cab8eb4629
exposed:              True
exposed-modules:      Test.Tasty.Inspection Test.Tasty.Inspection.Plugin
hidden-modules:       Test.Tasty.Inspection.Internal
import-dirs:
    /usr/lib/ghc-9.2.8/site-local/tasty-inspection-testing-0.2.1

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/tasty-inspection-testing-0.2.1

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-inspection-testing
hs-libraries:         HStasty-inspection-testing-0.2.1-4eXeMfIk9OsKHH1rKdGx4n
depends:
    base-4.16.4.0 ghc-9.2.8
    inspection-testing-0.5.0.3-2OudPLUZJQj32eoiHRYWC6
    tasty-1.4.3-2gR9WDhWbJHGLAofnQHAx7 template-haskell-2.18.0.0

haddock-interfaces:
    /usr/share/doc/haskell-tasty-inspection-testing/html/tasty-inspection-testing.haddock

haddock-html:         /usr/share/doc/haskell-tasty-inspection-testing/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
